#include <QtWebKit>
#include <QtGui>
#include <QDebug>

#include "mainwindow.h"
#include "webview.h"

int main(int argc, char *argv[])
{
    QApplication app(argc, argv);

    MainWindow window(NULL);
    window.show();  

    return app.exec();
}
